==> google_applovin_unity_ads-2.3.15.tar.gz: android/src/main/java/com/btcpiyush/ads/google_applovin_unity_ads/FlutterAppLovinWrapper.kt <==
// Copyright 2022 Bitcoding LLC
//
// See the License for the specific language governing permissions and
// limitations under the License.

package com.btcpiyush.ads.google_applovin_unity_ads

import android.content.Context
import android.content.pm.PackageManager
import android.text.TextUtils
import android.util.Log
import com.applovin.sdk.AppLovinPrivacySettings
import com.applovin.sdk.AppLovinSdk
import com.applovin.sdk.AppLovinSdk.SdkInitializationListener
import com.applovin.sdk.AppLovinSdkConfiguration
import com.applovin.sdk.AppLovinSdkSettings

/** A wrapper around static methods in [AppLovin].  */
class FlutterAppLovinWrapper {

    private var _appLovinSDK: AppLovinSdk? = null

    /** Retrieve the sdk key.  */
    fun initializeSDK(
        context: Context?, appLovinSdkKey: String
    ) {
        var sdkKey = appLovinSdkKey
        Log.e("initializeSDK: ", sdkKey)
        if (TextUtils.isEmpty(sdkKey)) {
            Log.e(" = == == = = =", "initializeSDK: TextUtils is Empty")
            try {
                Log.e(" = == == = = =", "initializeSDK: context checking")
                context?.let {
                    Log.e(" = == == = = =", "initializeSDK: context is done")
                    val packageManager = it.packageManager
                    val packageName = it.packageName
                    val applicationInfo = packageManager.getApplicationInfo(
                        packageName,
                        PackageManager.GET_META_DATA
                    )
                    val metaData = applicationInfo.metaData
                    sdkKey = metaData.getString("applovin.sdk.key", "")
                }
            } catch (th: Throwable) {
                th.printStackTrace()
            }
        }
        try {
            _appLovinSDK = AppLovinSdk.getInstance(
                sdkKey,
                AppLovinSdkSettings(context),
                context
            )
            AppLovinPrivacySettings.setIsAgeRestrictedUser(false, context)
        } catch (e: Exception) {
            Log.e("initializeSDK: ", e.message.toString())
            _appLovinSDK = null
        }

    }

    /** Initializes the sdk. */
    fun initialize(
        listener: SdkInitializationListener,
        geosdkfactory: GoogleApplovinUnityAdsPlugin.GeoedgeSdkFactory? = null,
        geoSdkkey: String? = null,
        timeoutInSeconds: Int? = 0
    ) {
        _appLovinSDK?.initializeSdk(listener)
        geoSdkkey?.let {
            geosdkfactory?.initializeGeoSdk(geoSdkkey, timeoutInSeconds ?: 0)
        }
    }

    /** Wrapper for setMediationProvider.  */
    fun setMediationProvider(provider: String) {
        _appLovinSDK?.mediationProvider = provider
    }

    /** Wrapper for setAppMuted.  */
    fun setAppMuted(muted: Boolean) {
        _appLovinSDK?.settings?.isMuted = muted
    }

    /** Wrapper for setVerboseLogging.  */
    fun setVerboseLogging(verboseLogging: Boolean) {
        _appLovinSDK?.settings?.setVerboseLogging(verboseLogging)
    }

    /** Wrapper for getRequestConfiguration.  */
    val requestConfiguration: AppLovinSdkConfiguration?
        get() = _appLovinSDK?.configuration

    fun getAppLovinSdk(): AppLovinSdk? {
        return _appLovinSDK
    }
}

==> google_applovin_unity_ads-2.3.18.tar.gz: android/src/main/java/com/btcpiyush/ads/google_applovin_unity_ads/FlutterAppLovinWrapper.kt <==
// Copyright 2022 Bitcoding LLC
//
// See the License for the specific language governing permissions and
// limitations under the License.

package com.btcpiyush.ads.google_applovin_unity_ads

import android.content.Context
import android.content.pm.PackageManager
import android.text.TextUtils
import android.util.Log
import android.widget.Toast
import com.appharbr.sdk.configuration.AHSdkConfiguration
import com.appharbr.sdk.engine.AppHarbr
import com.appharbr.sdk.engine.InitializationFailureReason
import com.appharbr.sdk.engine.listeners.OnAppHarbrInitializationCompleteListener
import com.applovin.sdk.AppLovinPrivacySettings
import com.applovin.sdk.AppLovinSdk
import com.applovin.sdk.AppLovinSdk.SdkInitializationListener
import com.applovin.sdk.AppLovinSdkConfiguration
import com.applovin.sdk.AppLovinSdkSettings

/** A wrapper around static methods in [AppLovin].  */
class FlutterAppLovinWrapper {

    private var _appLovinSDK: AppLovinSdk? = null

    /** Retrieve the sdk key.  */
    fun initializeSDK(
        context: Context?, appLovinSdkKey: String
    ) {
        var sdkKey = appLovinSdkKey
        Log.e("initializeSDK: ", sdkKey)
        if (TextUtils.isEmpty(sdkKey)) {
            Log.e(" = == == = = =", "initializeSDK: TextUtils is Empty")
            try {
                Log.e(" = == == = = =", "initializeSDK: context checking")
                context?.let {
                    Log.e(" = == == = = =", "initializeSDK: context is done")
                    val packageManager = it.packageManager
                    val packageName = it.packageName
                    val applicationInfo = packageManager.getApplicationInfo(
                        packageName,
                        PackageManager.GET_META_DATA
                    )
                    val metaData = applicationInfo.metaData
                    sdkKey = metaData.getString("applovin.sdk.key", "")
                }
            } catch (th: Throwable) {
                th.printStackTrace()
            }
        }

        try {
            _appLovinSDK = AppLovinSdk.getInstance(
                sdkKey,
                AppLovinSdkSettings(context),
                context
            )
            AppLovinPrivacySettings.setIsAgeRestrictedUser(false, context)
        } catch (e: Exception) {
            Log.e("initializeSDK: ", e.message.toString())
            _appLovinSDK = null
        }

    }

    /** Initializes the sdk. */
    fun initialize(
        listener: SdkInitializationListener,
        context: Context?,
        geoSdkkey: String? = null,
        timeoutInSeconds: Int? = 0
    ) {
        _appLovinSDK?.initializeSdk(listener)
        geoSdkkey?.let {
            context?.let { context ->
                val ahSdkConfiguration = AHSdkConfiguration.Builder(geoSdkkey)
                    .withMuteAd(true)
                    .withInterstitialAdTimeLimit(timeoutInSeconds ?: 0)
                    .build()

                AppHarbr.initialize(context,
                    ahSdkConfiguration,
                    object : OnAppHarbrInitializationCompleteListener {
                        override fun onSuccess() {}

                        override fun onFailure(reason: InitializationFailureReason) {}
                    })
            }
        }
    }

    /** Wrapper for setMediationProvider.  */
    fun setMediationProvider(provider: String) {
        _appLovinSDK?.mediationProvider = provider
    }

    /** Wrapper for setAppMuted.  */
    fun setAppMuted(muted: Boolean) {
        _appLovinSDK?.settings?.isMuted = muted
    }

    /** Wrapper for setVerboseLogging.  */
    fun setVerboseLogging(verboseLogging: Boolean) {
        _appLovinSDK?.settings?.setVerboseLogging(verboseLogging)
    }

    /** Wrapper for getRequestConfiguration.  */
    val requestConfiguration: AppLovinSdkConfiguration?
        get() = _appLovinSDK?.configuration

    fun getAppLovinSdk(): AppLovinSdk? {
        return _appLovinSDK
    }
}
